@@ -47,8 +47,10 @@ MVA.trajplot <- function(x,xax=1,yax=2,trajects,trajlab=NULL,scaling=2,set=c(12,
   coordy <- coord[,2]
   if (is.null(xlab)) {xlab <- colnames(coord)[1]}
   if (is.null(ylab)) {ylab <- colnames(coord)[2]}
-  if (is.null(xlim)) {xlim <- range(coordx)}
-  if (is.null(ylim)) {ylim <- range(coordy)}
+  xy.min <- min(min(coordx),min(coordy))
+  xy.max <- max(max(coordx),max(coordy))
+  if (is.null(xlim)) {xlim <- c(xy.min,xy.max)}
+  if (is.null(ylim)) {ylim <- c(xy.min,xy.max)}
   plot(coordx,coordy,xlab="",ylab="",xlim=xlim,ylim=ylim,axes=FALSE,type="n")
   if(drawextaxes) {
     axis(1)
